@@ -24,22 +24,14 @@
 //
 package javax.persistence;
 
-import java.lang.annotation.Target;
+import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;
-import static java.lang.annotation.ElementType.TYPE;
-import static java.lang.annotation.ElementType.METHOD;
-import static java.lang.annotation.ElementType.FIELD;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-
-
-@Target({TYPE, METHOD, FIELD}) 
-@Retention(RUNTIME)
+import java.lang.annotation.RetentionPolicy;
+import java.lang.annotation.Target;
 
+@Target({ElementType.TYPE, ElementType.METHOD, ElementType.FIELD})
+@Retention(RetentionPolicy.RUNTIME)
 public @interface AssociationOverride {
-
-    String name();
-
-    JoinColumn[] joinColumns() default {};
-
-    JoinTable joinTable() default @JoinTable;
+	String name(); 
+	JoinColumn[] joinColumns(); 
 }
