@@ -22,20 +22,10 @@
 // Community Process. In order to remain compliant with the specification
 // DO NOT add / change / or delete method signatures!
 //
-
 package javax.persistence;
 
-public enum CascadeType { 
-
-    ALL, 
-
-    PERSIST, 
-
-    MERGE, 
-
-    REMOVE,
-
-    REFRESH,
-
-    DETACH
-}
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (mer. 25 oct. 2006) $
+ */
+public enum CascadeType {
+    ALL, PERSIST, MERGE, REMOVE, REFRESH};
