@@ -26,13 +26,13 @@ package javax.persistence;
 
 import java.lang.annotation.Target;
 import java.lang.annotation.Retention;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-
-
-@Target({}) 
-@Retention(RUNTIME)
-
-public @interface ColumnResult { 
+import java.lang.annotation.RetentionPolicy;
 
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (mer. 25 oct. 2006) $
+ */
+@Target({})
+@Retention(RetentionPolicy.RUNTIME)
+public @interface ColumnResult {
     String name();
 }
