@@ -24,12 +24,8 @@
 //
 package javax.persistence;
 
-
-public enum DiscriminatorType { 
-
-    STRING,
-
-    CHAR,
-
-    INTEGER
-}
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (mer. 25 oct. 2006) $
+ */
+public enum DiscriminatorType {
+    STRING, CHAR, INTEGER };
