@@ -22,30 +22,20 @@
 // Community Process. In order to remain compliant with the specification
 // DO NOT add / change / or delete method signatures!
 //
-
-
 package javax.persistence;
 
-import java.util.Set;
 import java.util.Map;
-import javax.persistence.metamodel.Metamodel;
-import javax.persistence.criteria.CriteriaBuilder;
-
 
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (mer. 25 oct. 2006) $
+ */
 public interface EntityManagerFactory {
 
-    public EntityManager createEntityManager();
-    public EntityManager createEntityManager(Map map);
+	EntityManager createEntityManager();
+	
+	EntityManager createEntityManager(Map map);
 
-    public CriteriaBuilder getCriteriaBuilder();
-    public Metamodel getMetamodel();
+	void close();
 
-    public boolean isOpen();
-    public void close();
-
-    public Map<String, Object> getProperties();
-
-    public Cache getCache();
-
-    public PersistenceUnitUtil getPersistenceUnitUtil();
+	public boolean isOpen();
 }
