@@ -24,17 +24,16 @@
 //
 package javax.persistence;
 
-import java.lang.annotation.Target;
 import java.lang.annotation.Retention;
-import static java.lang.annotation.ElementType.FIELD;
-import static java.lang.annotation.ElementType.METHOD;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-import static javax.persistence.EnumType.ORDINAL;
+import java.lang.annotation.Target;
+import java.lang.annotation.ElementType;
+import java.lang.annotation.RetentionPolicy;
 
-
-@Target({METHOD, FIELD}) 
-@Retention(RUNTIME)
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (mer. 25 oct. 2006) $
+ */
+@Target({ElementType.METHOD, ElementType.FIELD})
+@Retention(RetentionPolicy.RUNTIME)
 public @interface Enumerated {
-
-    EnumType value() default ORDINAL;
+    EnumType value() default EnumType.ORDINAL;
 }
