@@ -21,13 +21,11 @@
 // This source code implements specifications defined by the Java
 // Community Process. In order to remain compliant with the specification
 // DO NOT add / change / or delete method signatures!
-//
 package javax.persistence;
 
-
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (Mi, 25 Okt 2006) $
+ */
 public enum FlushModeType {
-
-   COMMIT,
-
-   AUTO
+    COMMIT, AUTO
 }
