@@ -24,14 +24,9 @@
 //
 package javax.persistence;
 
-
-public enum GenerationType { 
-
-    TABLE, 
-
-    SEQUENCE, 
-
-    IDENTITY, 
-
-    AUTO
-}
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (mer. 25 oct. 2006) $
+ */
+public enum GenerationType {
+    TABLE, SEQUENCE, IDENTITY, AUTO
+};
