@@ -22,19 +22,19 @@
 // Community Process. In order to remain compliant with the specification
 // DO NOT add / change / or delete method signatures!
 //
+
 package javax.persistence;
 
-import java.lang.annotation.Target;
 import java.lang.annotation.Retention;
-import static java.lang.annotation.ElementType.TYPE;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-import static javax.persistence.InheritanceType.SINGLE_TABLE;
-
-
-@Target({TYPE})
-@Retention(RUNTIME)
+import java.lang.annotation.Target;
+import java.lang.annotation.RetentionPolicy;
+import java.lang.annotation.ElementType;
 
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (Mi, 25 Okt 2006) $
+ */
+@Target({ElementType.TYPE})
+@Retention(RetentionPolicy.RUNTIME)
 public @interface Inheritance {
-
-    InheritanceType strategy() default SINGLE_TABLE;
+    InheritanceType strategy() default InheritanceType.SINGLE_TABLE;
 }
