@@ -24,12 +24,9 @@
 //
 package javax.persistence;
 
-
-public enum InheritanceType { 
-
-    SINGLE_TABLE, 
-
-    TABLE_PER_CLASS, 
-
-    JOINED 
-}
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (Mi, 25 Okt 2006) $
+ */
+public enum InheritanceType {
+    SINGLE_TABLE, JOINED, TABLE_PER_CLASS
+};
