@@ -24,22 +24,9 @@
 //
 package javax.persistence;
 
-
-public enum LockModeType
-{
-    READ,
-
-    WRITE,
-
-    OPTIMISTIC,
-
-    OPTIMISTIC_FORCE_INCREMENT,
-
-    PESSIMISTIC_READ,
-
-    PESSIMISTIC_WRITE,
-
-    PESSIMISTIC_FORCE_INCREMENT,
-
-    NONE
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (Mi, 25 Okt 2006) $
+ */
+public enum LockModeType {
+    READ, WRITE
 }
