@@ -25,22 +25,23 @@
 package javax.persistence;
 
 import java.lang.annotation.Target;
+import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;
-import static java.lang.annotation.ElementType.TYPE;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-
-
-@Target({TYPE}) 
-@Retention(RUNTIME)
-public @interface NamedNativeQuery { 
+import java.lang.annotation.RetentionPolicy;
 
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (Mi, 25 Okt 2006) $
+ */
+@Target({ElementType.TYPE})
+@Retention(RetentionPolicy.RUNTIME)
+public @interface NamedNativeQuery {
     String name();
 
     String query();
 
     QueryHint[] hints() default {};
 
-    Class resultClass() default void.class; 
+    Class resultClass() default void.class;
 
     String resultSetMapping() default "";
 }
