@@ -25,20 +25,19 @@
 package javax.persistence;
 
 import java.lang.annotation.Target;
+import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;
-import static javax.persistence.LockModeType.NONE;
-import static java.lang.annotation.ElementType.TYPE;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
+import java.lang.annotation.RetentionPolicy;
 
-
-@Target({TYPE}) 
-@Retention(RUNTIME)
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (Mi, 25 Okt 2006) $
+ */
+@Target({ElementType.TYPE})
+@Retention(RetentionPolicy.RUNTIME)
 public @interface NamedQuery {
-
     String name();
 
     String query();
 
-    LockModeType lockMode() default NONE;
     QueryHint[] hints() default {};
 }
