@@ -24,10 +24,9 @@
 //
 package javax.persistence;
 
-
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (Mi, 25 Okt 2006) $
+ */
 public enum PersistenceContextType {
-
-    TRANSACTION,
-
-    EXTENDED
-}
+    TRANSACTION, EXTENDED
+}
\ No newline at end of file
