@@ -24,22 +24,26 @@
 //
 package javax.persistence;
 
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (Mi, 25 Okt 2006) $
+ */
 public class PersistenceException extends RuntimeException {
+ 
+    private static final long serialVersionUID = -8734504053550505412L;
 
     public PersistenceException() {
         super();
     }
 
-    public PersistenceException(String message) {
-        super(message);
+    public PersistenceException(String string) {
+        super(string);
     }
 
-    public PersistenceException(String message, Throwable cause) {
-        super(message, cause);
+    public PersistenceException(String string, Throwable throwable) {
+        super(string, throwable);
     }
 
-    public PersistenceException(Throwable cause) {
-        super(cause);
+    public PersistenceException(Throwable throwable) {
+        super(throwable);
     }
 }
-
