@@ -24,17 +24,14 @@
 //
 package javax.persistence;
 
-import java.lang.annotation.Target;
 import java.lang.annotation.Retention;
-import static java.lang.annotation.RetentionPolicy.*;
-
+import java.lang.annotation.RetentionPolicy;
+import java.lang.annotation.Target;
 
 @Target({})
-@Retention(RUNTIME)
+@Retention(RetentionPolicy.RUNTIME)
 public @interface PersistenceProperty {
+	String name();
 
-    String name();
-
-    String value();
-
+	String value();
 }
