@@ -25,17 +25,15 @@
 package javax.persistence;
 
 import java.lang.annotation.Target;
-import static java.lang.annotation.ElementType.*;
 import java.lang.annotation.Retention;
-import static java.lang.annotation.RetentionPolicy.*;
+import java.lang.annotation.RetentionPolicy;
+import java.lang.annotation.ElementType;
 
-
-
-
-@Target({TYPE})
-@Retention(RUNTIME)
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (mer. 25 oct. 2006) $
+ */
+@Target(ElementType.TYPE)
+@Retention(RetentionPolicy.RUNTIME)
 public @interface PersistenceUnits {
-
     PersistenceUnit[] value();
-
 }
