@@ -26,15 +26,15 @@ package javax.persistence;
 
 import java.lang.annotation.Target;
 import java.lang.annotation.Retention;
-import static java.lang.annotation.ElementType.TYPE;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-
-
-@Target(TYPE) 
-@Retention(RUNTIME)
+import java.lang.annotation.RetentionPolicy;
+import java.lang.annotation.ElementType;
 
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (mer. 25 oct. 2006) $
+ */
+@Target({ElementType.TYPE})
+@Retention(RetentionPolicy.RUNTIME)
 public @interface SecondaryTable {
-
     String name();
 
     String catalog() default "";
@@ -45,3 +45,4 @@ public @interface SecondaryTable {
 
     UniqueConstraint[] uniqueConstraints() default {};
 }
+
