@@ -26,15 +26,16 @@ package javax.persistence;
 
 import java.lang.annotation.Target;
 import java.lang.annotation.Retention;
-import static java.lang.annotation.ElementType.TYPE;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
+import java.lang.annotation.ElementType;
+import java.lang.annotation.RetentionPolicy;
 
-
-@Target({TYPE}) 
-@Retention(RUNTIME)
-public @interface SqlResultSetMapping { 
-
-    String name(); 
+/**
+ * @version $Rev: 489260 $ $Date: 2006-12-21 05:15:07 +0100 (Do, 21 Dez 2006) $
+ */
+@Target({ElementType.TYPE})
+@Retention(RetentionPolicy.RUNTIME)
+public @interface SqlResultSetMapping {
+    String name();
 
     EntityResult[] entities() default {};
 
