@@ -27,14 +27,13 @@ package javax.persistence;
 
 import java.lang.annotation.Target;
 import java.lang.annotation.Retention;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
+import java.lang.annotation.RetentionPolicy;
 
-
-@Target({}) 
-@Retention(RUNTIME)
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (mer. 25 oct. 2006) $
+ */
+@Target({})
+@Retention(RetentionPolicy.RUNTIME)
 public @interface UniqueConstraint {
-
-    String name() default "";
-
     String[] columnNames();
 }
