@@ -22,19 +22,18 @@
 // Community Process. In order to remain compliant with the specification
 // DO NOT add / change / or delete method signatures!
 //
-
 package javax.persistence.spi;
 
 import javax.persistence.EntityManagerFactory;
 import java.util.Map;
 
-
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (Mi, 25 Okt 2006) $
+ */
 public interface PersistenceProvider {
 
     public EntityManagerFactory createEntityManagerFactory(String emName, Map map);
 
     public EntityManagerFactory createContainerEntityManagerFactory(PersistenceUnitInfo info, Map map);
 
-    public ProviderUtil getProviderUtil();
 }
-
