@@ -22,13 +22,11 @@
 // Community Process. In order to remain compliant with the specification
 // DO NOT add / change / or delete method signatures!
 //
-
 package javax.persistence.spi;
 
-
+/**
+ * @version $Rev: 467742 $ $Date: 2006-10-25 21:30:38 +0200 (mer. 25 oct. 2006) $
+ */
 public enum PersistenceUnitTransactionType {
-
-    JTA,
-
-    RESOURCE_LOCAL
-}
+    JTA, RESOURCE_LOCAL
+}
\ No newline at end of file
